==> newsx_1.2.orig.tar.gz: newsx-1.2/acconfig.h <==
/*  $Id: acconfig.h,v 1.17 1998/09/18 07:30:51 src Exp $
 * 
 *  Autoconf additional symbols
 *
 *  copyright 1997 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  $Log: acconfig.h,v $
 *  Revision 1.17  1998/09/18 07:30:51  src
 *  Implemented --inews
 *
 *  Revision 1.16  1998/09/11 16:37:36  src
 *  Lockfile for logfile of posted articles and for posted article folder.
 *
 *  Revision 1.15  1998/09/11 09:11:04  src
 *  Check for putenv and setenv, support --help
 *
 *  Revision 1.14  1998/09/09 07:32:06  src
 *  Version 1.1
 *
 *  Revision 1.13  1998/08/24 07:10:50  src
 *  Removed HAVE_SENDMAIL and HAVE_RNEWS
 *
 *  Revision 1.12  1998/07/12 09:39:14  src
 *  newsx version 1.0
 */


/* Needed by AM_C_PROTOTYPES (BUG: required?) */
#undef PROTOTYPES

/* "newsx" */
#undef PACKAGE

/* "1.0" */
#undef VERSION

/* "Copyright 1998 Egil Kvaleberg <egil(at)kvaleberg.no>" */
#undef COPYRIGHT

/* "bug-newsx(at)kvaleberg.no" */
#undef BUGCATCHER

/* "/usr/lib/news" */
#undef NEWSHOME

/* "/usr/lib/newsbin" */
#undef NEWSBIN

/* "/usr/lib/news/active" */
#undef ACTIVE

/* "/usr/lib/news/history" */
#undef HISTORY

/* "usr/lib/news/newsfeeds" */
#undef NEWSFEEDS

/* "/var/spool/news" */
#undef SPOOL

/* "/var/spool/news/out.going" */
#undef BATCH

/* "/var/spool/news/in.coming" */
#undef INCOMING

/* "/var/spool/news/in.hosts" */
#undef INHOSTS

/* "/usr/lib/news" */
#undef LOCKS

/* "/usr/lib/news" */
#undef NEWSLIB

/* "/usr/bin/sendmail" */
#undef SENDMAIL_PATH

/* "/usr/bin/rnews" */
#undef RNEWS_PATH

/* "/usr/bin/inews" */
#undef INEWS_PATH

/* 0 */
#undef INN_MODE

/* 3 or 6 */
#undef DBZ_VERSION

/* 002 */
#undef NEWSUMASK

/* 1 */
#undef WITH_HISTORY

/* "LOG_NEWS" */
#undef WITH_ERRLOG
#undef WITHOUT_ERRLOG

/* 100000 */
#undef MINSPOOL

/* 600 */
#undef TIMEOUT

/* for dbz v.6 (INN 2.0) */
#undef DO_TAGGED_HASH

/* modify status (i.e. command line) available for the 'ps' command */
#undef PS_STATUS

/* short */
#undef nlink_t

/* __attribute__((packed)) */
#undef PACKED

==> newsx_1.4.orig.tar.gz: newsx-1.4/acconfig.h <==
/*  $Id: acconfig.h,v 1.22 1999/04/19 03:32:30 src Exp $
 * 
 *  Autoconf additional symbols
 *
 *  copyright 1997 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  $Log: acconfig.h,v $
 *  Revision 1.22  1999/04/19 03:32:30  src
 *  Standard profile in $PATHETC/newsx.conf
 *
 *  Revision 1.21  1999/04/08 10:48:48  src
 *  Extendeddbz to configure
 *
 *  Revision 1.20  1999/04/08 10:19:33  src
 *  Check for extendeddbz in configure
 *
 *  Revision 1.19  1999/03/07 15:41:24  src
 *  Removed DBZ_VERSION from configuration
 *
 *  Revision 1.18  1999/03/07 14:58:07  src
 *  Read newsconfig supported. Storage API supported.
 *
 *  Revision 1.17  1998/09/18 07:30:51  src
 *  Implemented --inews
 *
 *  Revision 1.16  1998/09/11 16:37:36  src
 *  Lockfile for logfile of posted articles and for posted article folder.
 *
 *  Revision 1.15  1998/09/11 09:11:04  src
 *  Check for putenv and setenv, support --help
 *
 *  Revision 1.14  1998/09/09 07:32:06  src
 *  Version 1.1
 *
 *  Revision 1.13  1998/08/24 07:10:50  src
 *  Removed HAVE_SENDMAIL and HAVE_RNEWS
 *
 *  Revision 1.12  1998/07/12 09:39:14  src
 *  newsx version 1.0
 */


/* Needed by AM_C_PROTOTYPES (BUG: required?) */
#undef PROTOTYPES

/* "newsx" */
#undef PACKAGE

/* "1.0" */
#undef VERSION

/* "Copyright 1998 Egil Kvaleberg <egil(at)kvaleberg.no>" */
#undef COPYRIGHT

/* "bug-newsx(at)kvaleberg.no" */
#undef BUGCATCHER

/* "/usr/lib/news" */
#undef NEWSHOME

/* "/usr/lib/news/bin/config" */
#undef NEWSCONFIG

/* "/usr/lib/newsbin" */
#undef NEWSBIN

/* "/usr/lib/news" */
#undef PATHETC

/* "/usr/lib/news/active" */
#undef ACTIVE

/* "/usr/lib/news/history" */
#undef HISTORY

/* "usr/lib/news/newsfeeds" */
#undef NEWSFEEDS

/* "/var/spool/news" */
#undef SPOOL

/* "/var/spool/news/out.going" */
#undef BATCH

/* "/var/spool/news/in.coming" */
#undef INCOMING

/* "/var/spool/news/in.hosts" */
#undef INHOSTS

/* "/usr/lib/news" */
#undef LOCKS

/* "/usr/lib/news" */
#undef NEWSLIB

/* "/usr/bin/sendmail" */
#undef SENDMAIL_PATH

/* "/usr/bin/rnews" */
#undef RNEWS_PATH

/* "/usr/bin/inews" */
#undef INEWS_PATH

/* 0 */
#undef INN_MODE

/* 002 */
#undef NEWSUMASK

/* 1 */
#undef WITH_HISTORY

/* "LOG_NEWS" */
#undef WITH_ERRLOG
#undef WITHOUT_ERRLOG

/* 100000 */
#undef MINSPOOL

/* 600 */
#undef TIMEOUT

/* for INN 2.x and dbz v.6 */
#undef DO_TAGGED_HASH

/* for INN 2.x: storage-API available? */
#undef HAVE_LIBSTORAGE

/* for INN 2.x: using extended dbz? */
#undef INN_EXTENDEDDBZ

/* for INN 2.x: configured for storage API? */
#undef INN_STORAGEAPI

/* modify status (i.e. command line) available for the 'ps' command */
#undef PS_STATUS

/* short */
#undef nlink_t

/* __attribute__((packed)) */
#undef PACKED
